package com.tcctlo.law.controller;

import com.tcctlo.common.core.domain.AjaxResult;
import com.tcctlo.law.entity.IndexStatistics;
import com.tcctlo.law.service.IIndexService;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * 首页控制器
 */
@RestController
@RequestMapping("/caseIndex")
public class IndexController {

    @Resource
    private IIndexService iIndexService;

    /**
     * 案件类型统计  conflictStatistics
     *
     * @return 结果集
     */
    @GetMapping("/caseTypeStatistics")
    public AjaxResult caseTypeStatistics(@RequestParam("startTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date startTime,
                                         @RequestParam("endTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date endTime) {
        List<IndexStatistics> integerIntegerMap = iIndexService.caseTypeStatistics(startTime, endTime);
        return AjaxResult.success(integerIntegerMap);
    }

    /**
     * 利冲统计
     *
     * @return 结果集
     */
    @GetMapping("/conflictStatistics")
    public AjaxResult conflictStatistics(@RequestParam("startTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date startTime,
                                         @RequestParam("endTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date endTime) {
        List<IndexStatistics> integerIntegerMap = iIndexService.conflictStatistics(startTime, endTime);
        return AjaxResult.success(integerIntegerMap);
    }

    /**
     * 费用统计
     *
     * @return 结果集
     */
    @GetMapping("/costStatistics")
    public AjaxResult costStatistics(@RequestParam("startTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date startTime,
                                     @RequestParam("endTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date endTime) {
        List<IndexStatistics> integerIntegerMap = iIndexService.costStatistics(startTime, endTime);
        return AjaxResult.success(integerIntegerMap);
    }

    /**
     * 收益走势
     *
     * @return 结果集
     */
    @GetMapping("/earningsTrend")
    public AjaxResult earningsTrend(@RequestParam("startTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date startTime,
                                     @RequestParam("endTime") @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss") Date endTime) {
        List<IndexStatistics> integerIntegerMap = iIndexService.earningsTrend(startTime, endTime);
        return AjaxResult.success(integerIntegerMap);
    }


}
