package com.tcctlo.law.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.entity.CaseInformation;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.tcctlo.law.vo.CaseInformationListVO;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 案件信息表 Mapper 接口
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
public interface CaseInformationMapper extends BaseMapper<CaseInformation> {

    /**
     * 分页条件查询
     * @param page 分页对象
     * @param condition 条件参数
     * @return 结果集
     */
    Page<CaseInformationListVO> selectCondition(@Param("page") Page<CaseInformationListVO> page, @Param("condition") Map<String, Object> condition);

    /**
     * 修改案件审核状态
     * @param caseId 案件Id
     * @param auditStatus 审核状态吗
     * @return 结果集
     */
    int updateAuditStatusInt(@Param("caseId") Long caseId, @Param("auditStatus") Integer auditStatus);

    /**
     *
     * @param caseId 案件ID
     * @param amountReceived 收款金额
     * @return 结果集
     */
    int updateCaseAmount(@Param("caseId") Long caseId, @Param("amountReceived") BigDecimal amountReceived);

    /**
     * 根据案件ID查询案件信息
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformationListVO selectCaseById(@Param("id") Long id);


    /**
     * 案件归档
     * @param caseId 要归档的案件ID
     * @return 受影响记录数
     */
    int caseArchived(@Param("caseId") Long caseId);

    /**
     * 批量逻辑删除案件信息
     * @param longList 案件ID集合
     */
    int removeByIds(@Param("ids") List<Long> longList);

    /**
     * 判断案件是否有相关文件
     * @param id 案件id
     * @return 结果集
     */
    int selectCaseFileNum(@Param("id") Long id);

    /**
     * 根据案件ID查询案件信息
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformation selectCaseInfoById(@Param("id") Long id);

    /**
     * 案件审核
     * @param params 参数
     * @return 是否审核成功
     */
    boolean caseReview(@Param("params") Map<String, Object> params);

    /**
     * 案件撤销
     * @param params 参数
     * @return 是否撤销成功
     */
    Boolean claimWithdrawal(@Param("params") Map<String, Object> params);

    /**
     * 案件结案
     * @param params 参数
     * @return 结案结果
     */
    Boolean caseClosed(@Param("params") Map<String, Object> params);

    /**
     * 根据业务类型查询案件数量
     * @param type 业务类型
     * @return 结果集
     */
    Integer selectCountByBusinessType(@Param("type") Integer type,
                                      @Param("startTime")Date startTime,
                                      @Param("endTime")Date endTime);

    /**
     * 利冲统计
     * @param caseStatus 收案状态
     * @return 结果集
     */
    Integer conflictStatistics(@Param("caseStatus") Integer caseStatus,
                               @Param("startTime")Date startTime,
                               @Param("endTime")Date endTime);

    /**
     * 未收款统计
     * @return 结果集
     */
    Integer outstandingPayment(@Param("startTime")Date startTime,
                               @Param("endTime")Date endTime);

    /**
     * 部分收费统计
     * @return 结果集
     */
    Integer partialCharge(@Param("startTime")Date startTime,
                          @Param("endTime")Date endTime);

    /**
     * 逾期未收费
     * @return 结果集
     */
    Integer overdue(@Param("startTime")Date startTime,
                    @Param("endTime")Date endTime);
}
