package com.tcctlo.law.service.impl;

import cn.hutool.core.date.DateUtil;
import com.tcctlo.law.entity.CollectionRecord;
import com.tcctlo.law.entity.IndexStatistics;
import com.tcctlo.law.mapper.CaseInformationMapper;
import com.tcctlo.law.mapper.CollectionRecordMapper;
import com.tcctlo.law.service.ICollectionRecordService;
import com.tcctlo.law.service.IIndexService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;
import java.util.function.BiConsumer;
import java.util.function.Function;
import java.util.stream.Collectors;

@Service
public class IIndexServiceImpl implements IIndexService {

    @Resource
    private CaseInformationMapper caseInformationMapper;

    @Resource
    private CollectionRecordMapper recordMapper;

    @Override
    public List<IndexStatistics> caseTypeStatistics(Date startTime, Date endTime) {
        List<IndexStatistics> res = new ArrayList<>();
        res.add(new IndexStatistics("民商事业务", Double.valueOf(caseInformationMapper.selectCountByBusinessType(0, startTime, endTime))));
        res.add(new IndexStatistics("刑事辩护业务", Double.valueOf(caseInformationMapper.selectCountByBusinessType(1, startTime, endTime))));
        res.add(new IndexStatistics("行政复议及诉讼业务", Double.valueOf(caseInformationMapper.selectCountByBusinessType(2, startTime, endTime))));
        res.add(new IndexStatistics("企业常年法律顾问", Double.valueOf(caseInformationMapper.selectCountByBusinessType(3, startTime, endTime))));
        res.add(new IndexStatistics("企业专项法律顾问", Double.valueOf(caseInformationMapper.selectCountByBusinessType(4, startTime, endTime))));
        return res;
    }

    @Override
    public List<IndexStatistics> conflictStatistics(Date startTime, Date endTime) {
        List<IndexStatistics> res = new ArrayList<>();
        res.add(new IndexStatistics("利冲收案", Double.valueOf(caseInformationMapper.conflictStatistics(0, startTime, endTime))));
        res.add(new IndexStatistics("正常收案", Double.valueOf(caseInformationMapper.conflictStatistics(1, startTime, endTime))));
        res.add(new IndexStatistics("终止收案", Double.valueOf(caseInformationMapper.conflictStatistics(2, startTime, endTime))));
        res.add(new IndexStatistics("案件撤销", Double.valueOf(caseInformationMapper.conflictStatistics(3, startTime, endTime))));
        return res;
    }

    @Override
    public List<IndexStatistics> costStatistics(Date startTime, Date endTime) {
        List<IndexStatistics> res = new ArrayList<>();
        res.add(new IndexStatistics("未收款", Double.valueOf(caseInformationMapper.outstandingPayment(startTime, endTime))));
        res.add(new IndexStatistics("部分收费", Double.valueOf(caseInformationMapper.partialCharge(startTime, endTime))));
        res.add(new IndexStatistics("付款逾期", Double.valueOf(caseInformationMapper.overdue(startTime, endTime))));
        return res;
    }

    @Override
    public List<IndexStatistics> earningsTrend(Date startTime, Date endTime) {
        List<CollectionRecord> list = recordMapper.earningsTrend(startTime, endTime);
        Map<Date, List<CollectionRecord>> map = list.stream().collect(Collectors.groupingBy(item -> DateUtil.parse(DateUtil.format(item.getCreateTime(), "yyyy-MM-dd"))));
        TreeMap<Date, List<CollectionRecord>> treeMap = new TreeMap<>(map);
        List<IndexStatistics> res = new ArrayList<>();
        TreeMap<String, List<CollectionRecord>> itemMap = new TreeMap<>();
        treeMap.forEach((date, collectionRecords) -> itemMap.put(DateUtil.format(date, "yyyy-MM-dd"), collectionRecords));
        itemMap.forEach((s, collectionRecords) -> {
            IndexStatistics indexStatistics = new IndexStatistics();
            indexStatistics.setName(s);
            indexStatistics.setValue(collectionRecords.stream().mapToDouble(item -> item.getAmountReceived().doubleValue()).sum());
            res.add(indexStatistics);
        });
        return res;
    }
}
